@@ -1,21 +1,8 @@
-/*****************************************************************************
- * This file is part of KDevelop                                             *
- * Copyright 2011-2012 Sven Brauch <svenbrauch@googlemail.com>               *
- *                                                                           *
- * This program is free software; you can redistribute it and/or             *
- * modify it under the terms of the GNU General Public License as            *
- * published by the Free Software Foundation; either version 2 of            *
- * the License, or (at your option) any later version.                       *
- *                                                                           *
- * This program is distributed in the hope that it will be useful,           *
- * but WITHOUT ANY WARRANTY; without even the implied warranty of            *
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             *
- * GNU General Public License for more details.                              *
- *                                                                           *
- * You should have received a copy of the GNU General Public License         *
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.     *
- *****************************************************************************
- */
+/*
+    SPDX-FileCopyrightText: 2011-2012 Sven Brauch <svenbrauch@googlemail.com>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #ifndef GLOBALHELPERS_H
 #define GLOBALHELPERS_H
@@ -37,10 +24,7 @@
 
 #include <functional>
 
-#include "pythonduchainexport.h"
-#include "types/unsuretype.h"
 #include "declarations/functiondeclaration.h"
-#include "ast.h"
 
 using namespace KDevelop;
 
@@ -51,13 +35,13 @@ public:
     /** get search paths for python files **/
     static QVector<QUrl> getSearchPaths(const QUrl& workingOnDocument);
     static QStringList dataDirs;
-    static QString documentationFile;
+    static IndexedString documentationFile;
     static QStringList correctionFileDirs;
     static QString localCorrectionFileDir;
     static DUChainPointer<TopDUContext> documentationFileContext;
 
     static QStringList getDataDirs();
-    static QString getDocumentationFile();
+    static IndexedString getDocumentationFile();
     static ReferencedTopDUContext getDocumentationFileContext();
 
     static QUrl getCorrectionFile(const QUrl& document);
@@ -118,16 +102,16 @@ public:
             return types;
         }
         if ( type->whichType() == KDevelop::AbstractType::TypeUnsure ) {
-            UnsureType::Ptr unsure(type.cast<UnsureType>());
+            auto unsure = type.staticCast<UnsureType>();
             for ( unsigned int i = 0; i < unsure->typesSize(); i++ ) {
                 AbstractType::Ptr t = unsure->types()[i].abstractType();
                 if ( accept(t) ) {
-                    types << ( map ? map(t) : t.cast<T>() );
+                    types << ( map ? map(t) : t.dynamicCast<T>() );
                 }
             }
         }
         else if ( accept(type) ) {
-            types << ( map ? map(type) : type.cast<T>() );
+            types << ( map ? map(type) : type.dynamicCast<T>() );
         }
         return types;
     }
@@ -148,7 +132,7 @@ public:
      **/
     static FuncInfo functionForCalled(Declaration* called, bool isAlias=true);
 
-    static bool docstringContainsHint(const QString& comment, const QString& hintName, QStringList* args = 0) {
+    static bool docstringContainsHint(const QString& comment, const QString& hintName, QStringList* args = nullptr) {
         // TODO cache types! this is horribly inefficient
         const QString search = "! " + hintName + " !";
         int index = comment.indexOf(search);
@@ -180,7 +164,7 @@ public:
     {
         AbstractType::Ptr result(new IntegralType(IntegralType::TypeMixed));
         for ( T type : types ) {
-            result = Helper::mergeTypes(result, transform ? transform(type) : AbstractType::Ptr::staticCast(type));
+            result = Helper::mergeTypes(result, transform ? transform(type) : type);
         }
         return result;
     };
@@ -212,7 +196,10 @@ public:
       **/
     static Declaration* resolveAliasDeclaration(Declaration* decl);
 
-    static Declaration* declarationForName(const QualifiedIdentifier& identifier, const RangeInRevision& nodeRange,
+    static Declaration* declarationForName(const QString& name, const CursorInRevision& location,
+                                          DUChainPointer<const DUContext> context);
+
+    static Declaration* declarationForName(const Python::NameAst* name, CursorInRevision location,
                                            DUChainPointer<const DUContext> context);
 
     static QString getPythonExecutablePath(IProject* project);
